==> lfocus_0.527-1.tar.gz: lfocus-0.527/lfocuswi.py <==
import gtk, pygtk, os,sys,time,math,hildon,hildondesktop,dbus,gobject
import dbus.service
import dbus.mainloop.glib
from dbus.mainloop.glib import DBusGMainLoop
lfocus_pid=0
keyboard_stat=0
y_loc=40
led_vis=0
menu_vis=0
blinker_stat=0
mem6_stat=True
mem7_stat=True
mem8_stat=True
def led(event):
	stat=int(os.popen("/usr/share/lfocus/v4l2-ctl -C torch_intensity|awk '{print $2}'").read())
	os.popen("/usr/share/lfocus/v4l2-ctl -c torch_intensity="+str(int(not(stat))))
def rled(event):
	stat=int(os.popen("/usr/share/lfocus/v4l2-ctl -C indicator_intensity|awk '{print $2}'").read())
	os.popen("/usr/share/lfocus/v4l2-ctl -c indicator_intensity="+str(int(not(stat))*3))



class lfocus_object(dbus.service.Object):
	def __init__(self, conn, object_path='/com/nokia/lfocus_comms/lfocus_service/object'):
		dbus.service.Object.__init__(self, conn, object_path)
	@dbus.service.signal('com.nokia.lfocus_comms.lfocus_service')
	def lfocus_signal(self, message):
		pass




	@dbus.service.method('com.nokia.lfocus_comms.lfocus_service')
	def lfocus_led1(self):
		self.lfocus_signal('L1')
	@dbus.service.method('com.nokia.lfocus_comms.lfocus_service')
	def lfocus_led0(self):
		self.lfocus_signal('L0')
	@dbus.service.method('com.nokia.lfocus_comms.lfocus_service')
	def lfocus_rled1(self):
		self.lfocus_signal('RL1')
	@dbus.service.method('com.nokia.lfocus_comms.lfocus_service')
	def lfocus_rled0(self):
		self.lfocus_signal('RL0')





	@dbus.service.method('com.nokia.lfocus_comms.lfocus_service')
	def lfocus_led1_r(self):
		self.lfocus_signal('L1_R')
	@dbus.service.method('com.nokia.lfocus_comms.lfocus_service')
	def lfocus_led0_r(self):
		self.lfocus_signal('L0_R')
	@dbus.service.method('com.nokia.lfocus_comms.lfocus_service')
	def lfocus_rled1_r(self):
		self.lfocus_signal('RL1_R')
	@dbus.service.method('com.nokia.lfocus_comms.lfocus_service')
	def lfocus_rled0_r(self):
		self.lfocus_signal('RL0_R')





	@dbus.service.method("com.nokia.lfocus_comms.lfocus_service", in_signature='', out_signature='')
	def Exit(self):
		loop.quit()
dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
System_bus = dbus.SystemBus()
name = dbus.service.BusName('com.nokia.lfocus_comms.lfocus_service', System_bus)
object = lfocus_object(System_bus)


class lfocusplug(hildondesktop.StatusMenuItem):
	def __init__(self):
		hildondesktop.StatusMenuItem.__init__(self)
		dbus_loop = DBusGMainLoop()
		self.bus = dbus.SystemBus(mainloop=dbus_loop)
		
		self.shutter_button_obj = self.bus.get_object("org.freedesktop.Hal",	"/org/freedesktop/Hal/devices/platform_cam_shutter")
		self.shutter_button_iface = dbus.Interface(self.shutter_button_obj, 	"org.freedesktop.Hal.Device")
		self.bus.add_signal_receiver(	self.shutter_operaion, 
						signal_name=None, 
						dbus_interface=				"org.freedesktop.Hal.Device", 
						bus_name=				"org.freedesktop.Hal", 
						path=					"/org/freedesktop/Hal/devices/platform_cam_shutter")

		self.bus.add_signal_receiver(	self.signal_filter,
						dbus_interface = 			"com.nokia.lfocus_comms.lfocus_service",
						signal_name = "lfocus_signal")

		
		self.prox_sens_obj = self.bus.get_object("org.freedesktop.Hal",		"/org/freedesktop/Hal/devices/platform_proximity")
		self.prox_sens_iface = dbus.Interface(self.prox_sens_obj,		"org.freedesktop.Hal.Device")
		self.bus.add_signal_receiver(	self.lfocus_menu_toggle, 
						signal_name=None, 
						dbus_interface= 			"org.freedesktop.Hal.Device", 
						bus_name=				"org.freedesktop.Hal", 
						path=					"/org/freedesktop/Hal/devices/platform_proximity")
		
		self.camera_button_obj = self.bus.get_object("org.freedesktop.Hal",	"/org/freedesktop/Hal/devices/platform_cam_launch")
		self.camera_button_iface = dbus.Interface(self.camera_button_obj, "org.freedesktop.Hal.Device")

		self.bus.add_signal_receiver(	self.roger2, 
						signal_name=None, 
						dbus_interface= "org.freedesktop.Hal.Device", 
						bus_name="org.freedesktop.Hal", 
						path="/org/freedesktop/Hal/devices/platform_cam_launch")


		
		self.lfocus_obj= self.bus.get_object("com.nokia.lfocus_comms.lfocus_service","/com/nokia/lfocus_comms/lfocus_service/object")
		self.button7=gtk.ToggleButton()
		self.button7.set_active(True)
		button1 = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,hildon.BUTTON_ARRANGEMENT_VERTICAL)
		button1.connect("clicked",self.lfocus_menu)
		button2 = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,hildon.BUTTON_ARRANGEMENT_VERTICAL)
		button2.connect("clicked",self.changer)
		image1=gtk.image_new_from_icon_name("lfocus-64", 50)
		container=gtk.Table(1,2,True)
		button1.add(image1)
		self.image2=gtk.image_new_from_icon_name("keyoff", 50)
		button2.add(self.image2)
		container2=gtk.Table(1,2,False)
		container2.attach(button1,0,1,0,1)
		container2.attach(button2,1,2,0,1)
		self.add(container2)
		self.hide_all()
	def led_mem(self,stat):
		try:
			self.button3.set_active(stat)
			os.popen("/usr/share/lfocus/v4l2-ctl -c torch_intensity="+str(int(stat)))
		except:
			os.popen("/usr/share/lfocus/v4l2-ctl -c torch_intensity="+str(int(stat)))
	def rled_off(self):
		os.popen("/usr/share/lfocus/v4l2-ctl -c indicator_intensity=0")
	def ticker2(self,a,b):
		self.rled_off()
	def roger2(self,a,b):
		if (self.button7.get_active()):
				self.maintimer = gobject.timeout_add(1000, self.rled_off)
		if (self.button6.get_active()):
				stat=self.button3.get_active()
				self.maintimer = gobject.timeout_add(1000, self.led_mem,stat)
	def signal_filter(self,lfocus_string):
		global led_vis
		
		if lfocus_string=="L1":		
			if led_vis:
				if not(self.button3.get_active()):
					self.button3.set_active(True)
			else:
				led(123)
		if lfocus_string=="L0":		
			if led_vis:
				if self.button3.get_active():
					self.button3.set_active(False)
			else:
				led(123)
		if lfocus_string=="RL1":		
			if led_vis:
				self.button4.set_active(True)
			else:
				rled(123)
		if lfocus_string=="RL0":		
			if led_vis:
				self.button4.set_active(False)
			else:
				rled(123)

	def dstr(self,event):
		global led_vis
		global menu_vis
		led_vis=0
		menu_vis=0
	def lfocus_menu_toggle(self,a,b):
		if not(self.shutter_button_iface.GetProperty("button.state.value")):
			global menu_vis
			global led_vis
			menu_vis+=1
			if menu_vis == 2:
				if led_vis:
					self.dialog1.hide_all()
					self.dialog1.show_all()
				else:
					self.lfocus_menu(123)
			
			if menu_vis > 3:
				menu_vis=4
	def ledf(self,*args):
		stat=int(os.popen("/usr/share/lfocus/v4l2-ctl -C torch_intensity|awk '{print $2}'").read())
		if int(stat)==0:
			print "stat0"
			#self.lfocus_obj.lfocus_led1_r(dbus_interface="com.nokia.lfocus_comms.lfocus_service")
		if int(stat)==1:
			print "stat1"
			#self.lfocus_obj.lfocus_led0_r(dbus_interface="com.nokia.lfocus_comms.lfocus_service")
		led(123)
	def lfocus_menu(self,widget,data=None):
		global led_vis
		global menu_vis
		global mem7_stat
		global mem8_stat
		menu_vis=4
		led_vis=1		
		self.dialog1=gtk.Dialog("Live Focus")
		self.dialog1.set_size_request(800,50)
		self.dialog1.connect("destroy",self.dstr)		
		contain=gtk.Table(2, 1, False)		
		table = gtk.Table(3, 3, False)
		table.set_row_spacings(10)
		image3=gtk.image_new_from_icon_name("gtk-go-down", 50)
		button2 = gtk.Button()
		button2.add(image3)
		def go_up(se):
			global y_loc
			y_loc-=70
			if y_loc<40:
				y_loc=40
			pannable_area.jump_to(0, y_loc)
		def go_down(args):
			global y_loc
			y_loc+=70
			if y_loc>180:
				y_loc=180
			pannable_area.jump_to(0, y_loc)
		image3=gtk.image_new_from_icon_name("gtk-go-up", 50)
		button6 = gtk.Button()
		button6.add(image3)
		button6.connect("clicked",go_up)
		button2.connect("clicked",go_down)
		self.button3 = gtk.ToggleButton("LED")
		self.button4=gtk.ToggleButton("RLED")
		button5 = gtk.Button()
		image3=gtk.image_new_from_icon_name("general_clock", 50)
		button5.add(image3)
		stat=int(os.popen("/usr/share/lfocus/v4l2-ctl -C torch_intensity|awk '{print $2}'").read())
		self.button3.set_active(bool(stat))
		stat=int(os.popen("/usr/share/lfocus/v4l2-ctl -C indicator_intensity|awk '{print $2}'").read())
		self.button4.set_active(bool(stat))
		self.button3.connect("clicked", led)
		self.button4.connect("clicked", rled)
		button5.connect("clicked", self.show_diag)
		table.attach(self.button3, 0, 1, 1, 2)
		table.attach(self.button4, 1, 2, 1, 2)
		table.attach(button5, 2, 3, 1, 2)
		self.button6=gtk.ToggleButton("Rem.LED")
		self.button7=gtk.ToggleButton("Stop RLED")
		self.button8=gtk.ToggleButton("Timer.RLED")
		table.attach(self.button6, 0, 1, 2, 3)
		table.attach(self.button7, 1, 2, 2, 3)
		table.attach(self.button8, 2, 3, 2, 3)
		self.button6.set_active(mem7_stat)
		self.button7.set_active(mem7_stat)
		self.button8.set_active(mem8_stat)
		def mem6(self):
			global mem6_stat
			mem6_stat=self.get_active()
		def mem7(self):
			global mem7_stat
			mem7_stat=self.get_active()
		def mem8(self):
			global mem8_stat
			mem8_stat=self.get_active()
		self.button6.connect("clicked", mem7)
		self.button7.connect("clicked", mem7)
		self.button8.connect("clicked", mem8)
		button5.set_size_request(170,50)
		self.button4.set_size_request(170,50)
		self.button3.set_size_request(170,50)
		props = gtk.Adjustment(value=0,lower=0,upper=1023,step_incr=32,page_incr=32);
		self.sld = gtk.HScale(props)
		self.sld.set_digits(0)
		self.sld.set_value(int(os.popen("/usr/share/lfocus/v4l2-ctl -C focus_absolute|awk '{print $2}'").read()))
		self.sld.set_size_request(500,80)
		self.sld.set_draw_value(False)
		self.sld.connect('value-changed', self.set_focus)
		table.attach(self.sld, 0, 3, 0, 1)
		pannable_area = hildon.PannableArea()
		pannable_area.add_with_viewport(table)
		pannable_area.set_size_request(550,50)
		contain.attach(button6, 1, 2, 0, 1)
		contain.attach(button2, 2, 3, 0, 1)
		contain.attach(pannable_area, 0, 1, 0, 1)
		
		self.dialog1.vbox.add(contain)
		self.dialog1.show_all()
		global y_loc
		pannable_area.jump_to(0, y_loc)

	def show_diag(self,*args):
		def stopwatch(a,b,*args):
			self.dialog3.hide_all()
			self.dialog1.hide_all()
			global menu_vis
			menu_vis=0
			def start_capture():
				if (self.button8.get_active()):
					global blinker_stat
					blinker_stat=not(blinker_stat)
					os.popen("/usr/share/lfocus/v4l2-ctl -c indicator_intensity="+str(blinker_stat*3))
				os.popen("sudo lfocus start_capture &")

			def blink(h):
				global blinker_stat
				blinker_stat=not(blinker_stat)
				os.popen("/usr/share/lfocus/v4l2-ctl -c indicator_intensity="+str(blinker_stat*3))
				if h>1:
					blinker=gobject.timeout_add(1000,blink,h-1)
					blinker_stat=not(blinker_stat)
					os.popen("/usr/share/lfocus/v4l2-ctl -c indicator_intensity="+str(blinker_stat*3))
			


			banner = hildon.hildon_banner_show_information(self.dialog3, "lfocus-64",   "capturing in "+str(b)+" seconds") 
			if (self.button8.get_active()):
				blink(b)			

			self.maintimer = gobject.timeout_add(1000*b,start_capture)
		global diag_is_up
		diag_is_up=1		
		self.dialog3=gtk.Dialog("Stopwatch")
		self.dialog3.connect("destroy", self.dialog3.hide_all)
		self.dialog3.set_size_request(800,50)
		table = gtk.Table(1, 5, True)
		button0=gtk.Button("0s")
		button5=gtk.Button("5s")
		button10=gtk.Button("10s")
		button15=gtk.Button("15s")
		button20=gtk.Button("20s")
		button0.connect("clicked", stopwatch,.01)
		button5.connect("clicked", stopwatch,5)
		button10.connect("clicked", stopwatch,10)
		button15.connect("clicked", stopwatch,15)
		button20.connect("clicked", stopwatch,20)
		table.attach(button0, 4, 5, 0, 1)
		table.attach(button5, 3, 4, 0, 1)
		table.attach(button10, 2,3, 0, 1)
		table.attach(button15, 1, 2, 0, 1)
		table.attach(button20, 0, 1, 0, 1)
		self.dialog3.vbox.add(table)
		self.dialog3.show_all()
	def stop_autofocus(self,a,b):
		#os.popen("osso-xterm");
		self.focus_button_iface.SetPropertyBoolean("button.state.value",False)
		self.focus_button_iface.SetPropertyBoolean("button.state.value",False)
		self.focus_button_iface.SetPropertyBoolean("button.state.value",False)
	def shutter_operaion(self,a,b):
		global keyboard_stat
		if self.shutter_button_iface.GetProperty("button.state.value"):
			os.popen("sudo lfocus stop_stop_focus &")
			if keyboard_stat==1:
				os.popen("sudo lfocus stop &")
				os.popen("setxkbmap")
				os.popen("maemo-xinput-sounds &")
				self.image2.set_from_icon_name("keyoff",50)
				keyboard_stat=0
			os.popen("sudo lfocus stop_proximity")

			global menu_vis
			menu_vis=0
			self.hide_all()
			self.dialog1.hide_all()
			self.dialog2.hide_all()

		else :
			os.popen("sudo lfocus start_proximity")
			self.show_all()
	def app_quit(widget, data=None):
   		gtk.main_quit()
	def set_focus(self,index):
  		os.popen("/usr/share/lfocus/v4l2-ctl -c focus_absolute="+str(math.floor(self.sld.get_value())).replace(".0",""))
	def changer(self,*args):
		global keyboard_stat
		global lfocus_pid
		if keyboard_stat==0:
			os.popen("sudo lfocus start_stop_focus &")
			os.popen("xkbcomp /usr/share/lfocus/nozoom.xkb :0 >/dev/null 2>&1")
			os.popen("killall maemo-xinput-sounds")
			os.popen("sudo lfocus start &")
			self.image2.set_from_icon_name("keyon",50)
			keyboard_stat=1
		else :
			os.popen("sudo lfocus stop_stop_focus &")
			os.popen("sudo lfocus stop &")
			os.popen("setxkbmap")
			os.popen("maemo-xinput-sounds &")
			self.image2.set_from_icon_name("keyoff",50)
			keyboard_stat=0
hd_plugin_type = lfocusplug
if __name__ == "__main__":
	import gobject
	gobject.type_register(hd_plugin_type)
	obj = gobject.new(hd_plugin_type, plugin_id="Live_Focus")
	obj.show_all()
	gtk.main()

==> lfocus_0.528-1.tar.gz: lfocus-0.528/lfocuswi.py <==
import gtk, pygtk, os,sys,time,math,hildon,hildondesktop,dbus,gobject
import dbus.service
import dbus.mainloop.glib
from dbus.mainloop.glib import DBusGMainLoop
lfocus_pid=0
keyboard_stat=0
y_loc=40
led_vis=0
menu_vis=0
blinker_stat=0
mem6_stat=True
mem7_stat=True
mem8_stat=True
def led(event):
	stat=int(os.popen("/opt/lfocus/v4l2-ctl -C torch_intensity|awk '{print $2}'").read())
	os.popen("/opt/lfocus/v4l2-ctl -c torch_intensity="+str(int(not(stat))))
def rled(event):
	stat=int(os.popen("/opt/lfocus/v4l2-ctl -C indicator_intensity|awk '{print $2}'").read())
	os.popen("/opt/lfocus/v4l2-ctl -c indicator_intensity="+str(int(not(stat))*3))



class lfocus_object(dbus.service.Object):
	def __init__(self, conn, object_path='/com/nokia/lfocus_comms/lfocus_service/object'):
		dbus.service.Object.__init__(self, conn, object_path)
	@dbus.service.signal('com.nokia.lfocus_comms.lfocus_service')
	def lfocus_signal(self, message):
		pass




	@dbus.service.method('com.nokia.lfocus_comms.lfocus_service')
	def lfocus_led1(self):
		self.lfocus_signal('L1')
	@dbus.service.method('com.nokia.lfocus_comms.lfocus_service')
	def lfocus_led0(self):
		self.lfocus_signal('L0')
	@dbus.service.method('com.nokia.lfocus_comms.lfocus_service')
	def lfocus_rled1(self):
		self.lfocus_signal('RL1')
	@dbus.service.method('com.nokia.lfocus_comms.lfocus_service')
	def lfocus_rled0(self):
		self.lfocus_signal('RL0')





	@dbus.service.method('com.nokia.lfocus_comms.lfocus_service')
	def lfocus_led1_r(self):
		self.lfocus_signal('L1_R')
	@dbus.service.method('com.nokia.lfocus_comms.lfocus_service')
	def lfocus_led0_r(self):
		self.lfocus_signal('L0_R')
	@dbus.service.method('com.nokia.lfocus_comms.lfocus_service')
	def lfocus_rled1_r(self):
		self.lfocus_signal('RL1_R')
	@dbus.service.method('com.nokia.lfocus_comms.lfocus_service')
	def lfocus_rled0_r(self):
		self.lfocus_signal('RL0_R')





	@dbus.service.method("com.nokia.lfocus_comms.lfocus_service", in_signature='', out_signature='')
	def Exit(self):
		loop.quit()
dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
System_bus = dbus.SystemBus()
name = dbus.service.BusName('com.nokia.lfocus_comms.lfocus_service', System_bus)
object = lfocus_object(System_bus)


class lfocusplug(hildondesktop.StatusMenuItem):
	def __init__(self):
		hildondesktop.StatusMenuItem.__init__(self)
		dbus_loop = DBusGMainLoop()
		self.bus = dbus.SystemBus(mainloop=dbus_loop)
		
		self.shutter_button_obj = self.bus.get_object("org.freedesktop.Hal",	"/org/freedesktop/Hal/devices/platform_cam_shutter")
		self.shutter_button_iface = dbus.Interface(self.shutter_button_obj, 	"org.freedesktop.Hal.Device")
		self.bus.add_signal_receiver(	self.shutter_operaion, 
						signal_name=None, 
						dbus_interface=				"org.freedesktop.Hal.Device", 
						bus_name=				"org.freedesktop.Hal", 
						path=					"/org/freedesktop/Hal/devices/platform_cam_shutter")

		self.bus.add_signal_receiver(	self.signal_filter,
						dbus_interface = 			"com.nokia.lfocus_comms.lfocus_service",
						signal_name = "lfocus_signal")

		
		self.prox_sens_obj = self.bus.get_object("org.freedesktop.Hal",		"/org/freedesktop/Hal/devices/platform_proximity")
		self.prox_sens_iface = dbus.Interface(self.prox_sens_obj,		"org.freedesktop.Hal.Device")
		self.bus.add_signal_receiver(	self.lfocus_menu_toggle, 
						signal_name=None, 
						dbus_interface= 			"org.freedesktop.Hal.Device", 
						bus_name=				"org.freedesktop.Hal", 
						path=					"/org/freedesktop/Hal/devices/platform_proximity")
		
		self.camera_button_obj = self.bus.get_object("org.freedesktop.Hal",	"/org/freedesktop/Hal/devices/platform_cam_launch")
		self.camera_button_iface = dbus.Interface(self.camera_button_obj, "org.freedesktop.Hal.Device")

		self.bus.add_signal_receiver(	self.roger2, 
						signal_name=None, 
						dbus_interface= "org.freedesktop.Hal.Device", 
						bus_name="org.freedesktop.Hal", 
						path="/org/freedesktop/Hal/devices/platform_cam_launch")


		
		self.lfocus_obj= self.bus.get_object("com.nokia.lfocus_comms.lfocus_service","/com/nokia/lfocus_comms/lfocus_service/object")
		self.button7=gtk.ToggleButton()
		self.button7.set_active(True)
		button1 = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,hildon.BUTTON_ARRANGEMENT_VERTICAL)
		button1.connect("clicked",self.lfocus_menu)
		button2 = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,hildon.BUTTON_ARRANGEMENT_VERTICAL)
		button2.connect("clicked",self.changer)
		image1=gtk.image_new_from_file("/opt/lfocus/lfocus-64.png")
		container=gtk.Table(1,2,True)
		button1.add(image1)
		self.image2=gtk.image_new_from_file("/opt/lfocus/keyoff.png")
		button2.add(self.image2)
		container2=gtk.Table(1,2,False)
		container2.attach(button1,0,1,0,1)
		container2.attach(button2,1,2,0,1)
		self.add(container2)
		self.hide_all()
	def led_mem(self,stat):
		try:
			self.button3.set_active(stat)
			os.popen("/opt/lfocus/v4l2-ctl -c torch_intensity="+str(int(stat)))
		except:
			os.popen("/opt/lfocus/v4l2-ctl -c torch_intensity="+str(int(stat)))
	def rled_off(self):
		os.popen("/opt/lfocus/v4l2-ctl -c indicator_intensity=0")
	def ticker2(self,a,b):
		self.rled_off()
	def roger2(self,a,b):
		if (self.button7.get_active()):
				self.maintimer = gobject.timeout_add(1000, self.rled_off)
		if (self.button6.get_active()):
				stat=self.button3.get_active()
				self.maintimer = gobject.timeout_add(1000, self.led_mem,stat)
	def signal_filter(self,lfocus_string):
		global led_vis
		
		if lfocus_string=="L1":		
			if led_vis:
				if not(self.button3.get_active()):
					self.button3.set_active(True)
			else:
				led(123)
		if lfocus_string=="L0":		
			if led_vis:
				if self.button3.get_active():
					self.button3.set_active(False)
			else:
				led(123)
		if lfocus_string=="RL1":		
			if led_vis:
				self.button4.set_active(True)
			else:
				rled(123)
		if lfocus_string=="RL0":		
			if led_vis:
				self.button4.set_active(False)
			else:
				rled(123)

	def dstr(self,event):
		global led_vis
		global menu_vis
		led_vis=0
		menu_vis=0
	def lfocus_menu_toggle(self,a,b):
		if not(self.shutter_button_iface.GetProperty("button.state.value")):
			global menu_vis
			global led_vis
			menu_vis+=1
			if menu_vis == 2:
				if led_vis:
					self.dialog1.hide_all()
					self.dialog1.show_all()
				else:
					self.lfocus_menu(123)
			
			if menu_vis > 3:
				menu_vis=4
	def ledf(self,*args):
		stat=int(os.popen("/opt/lfocus/v4l2-ctl -C torch_intensity|awk '{print $2}'").read())
		if int(stat)==0:
			print "stat0"
			#self.lfocus_obj.lfocus_led1_r(dbus_interface="com.nokia.lfocus_comms.lfocus_service")
		if int(stat)==1:
			print "stat1"
			#self.lfocus_obj.lfocus_led0_r(dbus_interface="com.nokia.lfocus_comms.lfocus_service")
		led(123)
	def lfocus_menu(self,widget,data=None):
		global led_vis
		global menu_vis
		global mem7_stat
		global mem8_stat
		menu_vis=4
		led_vis=1		
		self.dialog1=gtk.Dialog("Live Focus")
		self.dialog1.set_size_request(800,50)
		self.dialog1.connect("destroy",self.dstr)		
		contain=gtk.Table(2, 1, False)		
		table = gtk.Table(3, 3, False)
		table.set_row_spacings(10)
		image3=gtk.image_new_from_icon_name("gtk-go-down", 50)
		button2 = gtk.Button()
		button2.add(image3)
		def go_up(se):
			global y_loc
			y_loc-=70
			if y_loc<40:
				y_loc=40
			pannable_area.jump_to(0, y_loc)
		def go_down(args):
			global y_loc
			y_loc+=70
			if y_loc>180:
				y_loc=180
			pannable_area.jump_to(0, y_loc)
		image3=gtk.image_new_from_icon_name("gtk-go-up", 50)
		button6 = gtk.Button()
		button6.add(image3)
		button6.connect("clicked",go_up)
		button2.connect("clicked",go_down)
		self.button3 = gtk.ToggleButton("LED")
		self.button4=gtk.ToggleButton("RLED")
		button5 = gtk.Button()
		image3=gtk.image_new_from_icon_name("general_clock", 50)
		button5.add(image3)
		stat=int(os.popen("/opt/lfocus/v4l2-ctl -C torch_intensity|awk '{print $2}'").read())
		self.button3.set_active(bool(stat))
		stat=int(os.popen("/opt/lfocus/v4l2-ctl -C indicator_intensity|awk '{print $2}'").read())
		self.button4.set_active(bool(stat))
		self.button3.connect("clicked", led)
		self.button4.connect("clicked", rled)
		button5.connect("clicked", self.show_diag)
		table.attach(self.button3, 0, 1, 1, 2)
		table.attach(self.button4, 1, 2, 1, 2)
		table.attach(button5, 2, 3, 1, 2)
		self.button6=gtk.ToggleButton("Rem.LED")
		self.button7=gtk.ToggleButton("Stop RLED")
		self.button8=gtk.ToggleButton("Timer.RLED")
		table.attach(self.button6, 0, 1, 2, 3)
		table.attach(self.button7, 1, 2, 2, 3)
		table.attach(self.button8, 2, 3, 2, 3)
		self.button6.set_active(mem7_stat)
		self.button7.set_active(mem7_stat)
		self.button8.set_active(mem8_stat)
		def mem6(self):
			global mem6_stat
			mem6_stat=self.get_active()
		def mem7(self):
			global mem7_stat
			mem7_stat=self.get_active()
		def mem8(self):
			global mem8_stat
			mem8_stat=self.get_active()
		self.button6.connect("clicked", mem7)
		self.button7.connect("clicked", mem7)
		self.button8.connect("clicked", mem8)
		button5.set_size_request(170,50)
		self.button4.set_size_request(170,50)
		self.button3.set_size_request(170,50)
		props = gtk.Adjustment(value=0,lower=0,upper=1023,step_incr=32,page_incr=32);
		self.sld = gtk.HScale(props)
		self.sld.set_digits(0)
		self.sld.set_value(int(os.popen("/opt/lfocus/v4l2-ctl -C focus_absolute|awk '{print $2}'").read()))
		self.sld.set_size_request(500,80)
		self.sld.set_draw_value(False)
		self.sld.connect('value-changed', self.set_focus)
		table.attach(self.sld, 0, 3, 0, 1)
		pannable_area = hildon.PannableArea()
		pannable_area.add_with_viewport(table)
		pannable_area.set_size_request(550,50)
		contain.attach(button6, 1, 2, 0, 1)
		contain.attach(button2, 2, 3, 0, 1)
		contain.attach(pannable_area, 0, 1, 0, 1)
		
		self.dialog1.vbox.add(contain)
		self.dialog1.show_all()
		global y_loc
		pannable_area.jump_to(0, y_loc)

	def show_diag(self,*args):
		def stopwatch(a,b,*args):
			self.dialog3.hide_all()
			self.dialog1.hide_all()
			global menu_vis
			menu_vis=0
			def start_capture():
				if (self.button8.get_active()):
					global blinker_stat
					blinker_stat=not(blinker_stat)
					os.popen("/opt/lfocus/v4l2-ctl -c indicator_intensity="+str(blinker_stat*3))
				os.popen("sudo lfocus start_capture &")

			def blink(h):
				global blinker_stat
				blinker_stat=not(blinker_stat)
				os.popen("/opt/lfocus/v4l2-ctl -c indicator_intensity="+str(blinker_stat*3))
				if h>1:
					blinker=gobject.timeout_add(1000,blink,h-1)
					blinker_stat=not(blinker_stat)
					os.popen("/opt/lfocus/v4l2-ctl -c indicator_intensity="+str(blinker_stat*3))
			


			banner = hildon.hildon_banner_show_information(self.dialog3, "lfocus-64",   "capturing in "+str(b)+" seconds") 
			if (self.button8.get_active()):
				blink(b)			

			self.maintimer = gobject.timeout_add(1000*b,start_capture)
		global diag_is_up
		diag_is_up=1		
		self.dialog3=gtk.Dialog("Stopwatch")
		self.dialog3.connect("destroy", self.dialog3.hide_all)
		self.dialog3.set_size_request(800,50)
		table = gtk.Table(1, 5, True)
		button0=gtk.Button("0s")
		button5=gtk.Button("5s")
		button10=gtk.Button("10s")
		button15=gtk.Button("15s")
		button20=gtk.Button("20s")
		button0.connect("clicked", stopwatch,.01)
		button5.connect("clicked", stopwatch,5)
		button10.connect("clicked", stopwatch,10)
		button15.connect("clicked", stopwatch,15)
		button20.connect("clicked", stopwatch,20)
		table.attach(button0, 4, 5, 0, 1)
		table.attach(button5, 3, 4, 0, 1)
		table.attach(button10, 2,3, 0, 1)
		table.attach(button15, 1, 2, 0, 1)
		table.attach(button20, 0, 1, 0, 1)
		self.dialog3.vbox.add(table)
		self.dialog3.show_all()
	def stop_autofocus(self,a,b):
		#os.popen("osso-xterm");
		self.focus_button_iface.SetPropertyBoolean("button.state.value",False)
		self.focus_button_iface.SetPropertyBoolean("button.state.value",False)
		self.focus_button_iface.SetPropertyBoolean("button.state.value",False)
	def shutter_operaion(self,a,b):
		global keyboard_stat
		if self.shutter_button_iface.GetProperty("button.state.value"):
			os.popen("sudo lfocus stop_stop_focus &")
			if keyboard_stat==1:
				os.popen("sudo lfocus stop &")
				os.popen("setxkbmap")
				os.popen("maemo-xinput-sounds &")
				self.image2.set_from_icon_name("keyoff",50)
				keyboard_stat=0
			os.popen("sudo lfocus stop_proximity")

			global menu_vis
			menu_vis=0
			self.hide_all()
			self.dialog1.hide_all()
			self.dialog2.hide_all()

		else :
			os.popen("sudo lfocus start_proximity")
			self.show_all()
	def app_quit(widget, data=None):
   		gtk.main_quit()
	def set_focus(self,index):
  		os.popen("/opt/lfocus/v4l2-ctl -c focus_absolute="+str(math.floor(self.sld.get_value())).replace(".0",""))
	def changer(self,*args):
		global keyboard_stat
		global lfocus_pid
		if keyboard_stat==0:
			os.popen("sudo lfocus start_stop_focus &")
			os.popen("xkbcomp /opt/lfocus/nozoom.xkb :0 >/dev/null 2>&1")
			os.popen("killall maemo-xinput-sounds")
			os.popen("sudo lfocus start &")
			self.image2.set_from_file("/opt/lfocus/keyon.png")
			keyboard_stat=1
		else :
			os.popen("sudo lfocus stop_stop_focus &")
			os.popen("sudo lfocus stop &")
			os.popen("setxkbmap")
			os.popen("maemo-xinput-sounds &")
			self.image2.set_from_file("/opt/lfocus/keyoff.png")
			keyboard_stat=0
hd_plugin_type = lfocusplug
if __name__ == "__main__":
	import gobject
	gobject.type_register(hd_plugin_type)
	obj = gobject.new(hd_plugin_type, plugin_id="Live_Focus")
	obj.show_all()
	gtk.main()
